@@ -6,13 +6,12 @@
 #' Please read the "Getting started" vignette.
 #' 
 #' @name Ryacas-package
-#' @docType package
 #' @useDynLib Ryacas, .registration = TRUE
 #' @importFrom Rcpp evalCpp
 #' @importFrom stats deriv
 #' @importFrom methods is
 #' @keywords programming
-NULL
+"_PACKAGE"
 
 
 #' Pipe operator
