@@ -1,7 +1,7 @@
 #include "yacas/patternclass.h"
 
-PatternClass::PatternClass(YacasPatternPredicateBase* aPatternMatcher)
-: iPatternMatcher(aPatternMatcher)
+PatternClass::PatternClass(YacasPatternPredicateBase* aPatternMatcher) :
+    iPatternMatcher(aPatternMatcher)
 {
 }
 
@@ -15,15 +15,13 @@ const char* PatternClass::TypeName() const
     return "\"Pattern\"";
 }
 
-bool PatternClass::Matches(LispEnvironment& aEnvironment,
-                                  LispPtr& aArguments)
+bool PatternClass::Matches(LispEnvironment& aEnvironment, LispPtr& aArguments)
 {
     assert(iPatternMatcher);
     return iPatternMatcher->Matches(aEnvironment, aArguments);
 }
 
-bool PatternClass::Matches(LispEnvironment& aEnvironment,
-                                  LispPtr* aArguments)
+bool PatternClass::Matches(LispEnvironment& aEnvironment, LispPtr* aArguments)
 {
     assert(iPatternMatcher);
     return iPatternMatcher->Matches(aEnvironment, aArguments);
