@@ -1,29 +1,27 @@
 #include "yacas/patterns.h"
-#include "yacas/standard.h"
-#include "yacas/mathuserfunc.h"
-#include "yacas/lispobject.h"
 #include "yacas/lispeval.h"
+#include "yacas/lispobject.h"
+#include "yacas/mathuserfunc.h"
 #include "yacas/standard.h"
 
 #include <memory>
 
 bool MatchAtom::ArgumentMatches(LispEnvironment& aEnvironment,
-                                       LispPtr& aExpression,
-                                       LispPtr* arguments) const
+                                LispPtr& aExpression,
+                                LispPtr* arguments) const
 {
     // If it is a floating point, don't even bother comparing
     if (!!aExpression)
-      if (aExpression->Number(0))
-        if (!aExpression->Number(0)->IsInt())
-          return false;
+        if (aExpression->Number(0))
+            if (!aExpression->Number(0)->IsInt())
+                return false;
 
     return (iString == aExpression->String());
 }
 
-
 bool MatchNumber::ArgumentMatches(LispEnvironment& aEnvironment,
-                                       LispPtr& aExpression,
-                                       LispPtr* arguments) const
+                                  LispPtr& aExpression,
+                                  LispPtr* arguments) const
 {
     if (aExpression->Number(aEnvironment.Precision()))
         return iNumber->Equals(*aExpression->Number(aEnvironment.Precision()));
@@ -32,8 +30,8 @@ bool MatchNumber::ArgumentMatches(LispEnvironment& aEnvironment,
 }
 
 bool MatchVariable::ArgumentMatches(LispEnvironment& aEnvironment,
-                                       LispPtr& aExpression,
-                                       LispPtr* arguments) const
+                                    LispPtr& aExpression,
+                                    LispPtr* arguments) const
 {
     if (!arguments[iVarIndex]) {
         arguments[iVarIndex] = aExpression;
@@ -47,52 +45,51 @@ bool MatchVariable::ArgumentMatches(LispEnvironment& aEnvironment,
 }
 
 bool MatchSubList::ArgumentMatches(LispEnvironment& aEnvironment,
-                                          LispPtr& aExpression,
-                                          LispPtr* arguments) const
+                                   LispPtr& aExpression,
+                                   LispPtr* arguments) const
 {
-  if (!aExpression->SubList())
-    return false;
+    if (!aExpression->SubList())
+        return false;
 
-  LispIterator iter(aExpression);
-  LispObject * pObj = iter.getObj();
+    LispIterator iter(aExpression);
+    LispObject* pObj = iter.getObj();
 
-  if (!pObj)
-      throw LispErrInvalidArg();
+    if (!pObj)
+        throw LispErrInvalidArg();
 
-  LispPtr * pPtr = pObj->SubList();
+    LispPtr* pPtr = pObj->SubList();
 
-  if (!pPtr)
-      throw LispErrNotList();
+    if (!pPtr)
+        throw LispErrNotList();
 
-  iter = *pPtr;
+    iter = *pPtr;
 
-  const int iNrMatchers = iMatchers.size();
-  for (int i=0;i<iNrMatchers;i++,++iter)
-  {
-    if (!iter.getObj())
-      return false;
-    if (!iMatchers[i]->ArgumentMatches(aEnvironment,*iter,arguments))
-      return false;
-  }
-  if (iter.getObj())
-    return false;
-  return true;
+    const int iNrMatchers = iMatchers.size();
+    for (int i = 0; i < iNrMatchers; i++, ++iter) {
+        if (!iter.getObj())
+            return false;
+        if (!iMatchers[i]->ArgumentMatches(aEnvironment, *iter, arguments))
+            return false;
+    }
+    if (iter.getObj())
+        return false;
+    return true;
 }
 
-int YacasPatternPredicateBase::LookUp(const LispString * aVariable)
+int YacasPatternPredicateBase::LookUp(const LispString* aVariable)
 {
     const std::size_t n = iVariables.size();
     for (std::size_t i = 0; i < n; ++i)
         if (iVariables[i] == aVariable)
             return i;
 
-    aVariable->iReferenceCount += 1;
     iVariables.push_back(aVariable);
     return iVariables.size() - 1;
 }
 
-
-const YacasParamMatcherBase* YacasPatternPredicateBase::MakeParamMatcher(LispEnvironment& aEnvironment, LispObject* aPattern)
+const YacasParamMatcherBase*
+YacasPatternPredicateBase::MakeParamMatcher(LispEnvironment& aEnvironment,
+                                            LispObject* aPattern)
 {
     if (!aPattern)
         return nullptr;
@@ -105,8 +102,7 @@ const YacasParamMatcherBase* YacasPatternPredicateBase::MakeParamMatcher(LispEnv
         return new MatchAtom(aPattern->String());
 
     // Else it must be a sublist
-    if (aPattern->SubList())
-    {
+    if (aPattern->SubList()) {
         // See if it is a variable template:
         LispPtr* sublist = aPattern->SubList();
         assert(sublist);
@@ -114,28 +110,21 @@ const YacasParamMatcherBase* YacasPatternPredicateBase::MakeParamMatcher(LispEnv
         int num = InternalListLength(*sublist);
 
         // variable matcher here...
-        if (num>1)
-        {
+        if (num > 1) {
             LispObject* head = (*sublist);
-            if (head->String() == aEnvironment.HashTable().LookUp("_"))
-            {
+            if (head->String() == aEnvironment.HashTable().LookUp("_")) {
                 LispObject* second = head->Nixed();
-                if (second->String())
-                {
+                if (second->String()) {
                     int index = LookUp(second->String());
 
                     // Make a predicate for the type, if needed
-                    if (num>2)
-                    {
+                    if (num > 2) {
                         LispPtr third;
 
                         LispObject* predicate = second->Nixed();
-                        if (predicate->SubList())
-                        {
+                        if (predicate->SubList()) {
                             InternalFlatCopy(third, *predicate->SubList());
-                        }
-                        else
-                        {
+                        } else {
                             third = (second->Nixed()->Copy());
                         }
 
@@ -143,7 +132,8 @@ const YacasParamMatcherBase* YacasPatternPredicateBase::MakeParamMatcher(LispEnv
                         while (!!last->Nixed())
                             last = last->Nixed();
 
-                        last->Nixed() = LispAtom::New(aEnvironment, *second->String());
+                        last->Nixed() =
+                            LispAtom::New(aEnvironment, *second->String());
 
                         iPredicates.push_back(LispPtr(LispSubList::New(third)));
                     }
@@ -156,7 +146,7 @@ const YacasParamMatcherBase* YacasPatternPredicateBase::MakeParamMatcher(LispEnv
         matchers.reserve(num);
         LispIterator iter(*sublist);
         for (int i = 0; i < num; ++i, ++iter) {
-            matchers.push_back(MakeParamMatcher(aEnvironment,iter.getObj()));
+            matchers.push_back(MakeParamMatcher(aEnvironment, iter.getObj()));
             assert(matchers[i]);
         }
         return new MatchSubList(std::move(matchers));
@@ -166,13 +156,12 @@ const YacasParamMatcherBase* YacasPatternPredicateBase::MakeParamMatcher(LispEnv
 }
 
 YacasPatternPredicateBase::YacasPatternPredicateBase(
-    LispEnvironment& aEnvironment,
-    LispPtr& aPattern,
-    LispPtr& aPostPredicate)
+    LispEnvironment& aEnvironment, LispPtr& aPattern, LispPtr& aPostPredicate)
 {
     for (LispIterator iter(aPattern); iter.getObj(); ++iter) {
-        const YacasParamMatcherBase* matcher = MakeParamMatcher(aEnvironment, iter.getObj());
-        assert(matcher!=nullptr);
+        const YacasParamMatcherBase* matcher =
+            MakeParamMatcher(aEnvironment, iter.getObj());
+        assert(matcher != nullptr);
         iParamMatchers.push_back(matcher);
     }
 
@@ -180,28 +169,30 @@ YacasPatternPredicateBase::YacasPatternPredicateBase(
 }
 
 bool YacasPatternPredicateBase::Matches(LispEnvironment& aEnvironment,
-                                              LispPtr& aArguments)
+                                        LispPtr& aArguments)
 {
-    std::unique_ptr<LispPtr[]> arguments(iVariables.empty() ? nullptr : new LispPtr[iVariables.size()]);
+    std::unique_ptr<LispPtr[]> arguments(
+        iVariables.empty() ? nullptr : new LispPtr[iVariables.size()]);
 
     LispIterator iter(aArguments);
     const std::size_t n = iParamMatchers.size();
 
     for (std::size_t i = 0; i < n; ++i, ++iter) {
-        
+
         if (!iter.getObj())
             return false;
-        
-        if (!iParamMatchers[i]->ArgumentMatches(aEnvironment, *iter, arguments.get()))
+
+        if (!iParamMatchers[i]->ArgumentMatches(
+                aEnvironment, *iter, arguments.get()))
             return false;
     }
-    
+
     if (iter.getObj())
         return false;
 
     {
         // set the local variables.
-        LispLocalFrame frame(aEnvironment,false);
+        LispLocalFrame frame(aEnvironment, false);
 
         SetPatternVariables(aEnvironment, arguments.get());
 
@@ -216,17 +207,16 @@ bool YacasPatternPredicateBase::Matches(LispEnvironment& aEnvironment,
     return true;
 }
 
-
-
-
 bool YacasPatternPredicateBase::Matches(LispEnvironment& aEnvironment,
-                                              LispPtr* aArguments)
+                                        LispPtr* aArguments)
 {
-    std::unique_ptr<LispPtr[]> arguments(iVariables.empty() ? nullptr : new LispPtr[iVariables.size()]);
+    std::unique_ptr<LispPtr[]> arguments(
+        iVariables.empty() ? nullptr : new LispPtr[iVariables.size()]);
 
     const std::size_t n = iParamMatchers.size();
     for (std::size_t i = 0; i < n; ++i)
-        if (!iParamMatchers[i]->ArgumentMatches(aEnvironment,aArguments[i],arguments.get()))
+        if (!iParamMatchers[i]->ArgumentMatches(
+                aEnvironment, aArguments[i], arguments.get()))
             return false;
 
     {
@@ -245,56 +235,46 @@ bool YacasPatternPredicateBase::Matches(LispEnvironment& aEnvironment,
     return true;
 }
 
-
-
 bool YacasPatternPredicateBase::CheckPredicates(LispEnvironment& aEnvironment)
 {
     const std::size_t n = iPredicates.size();
-  for (std::size_t i = 0; i < n; ++i)
-  {
-    LispPtr pred;
-    aEnvironment.iEvaluator->Eval(aEnvironment, pred, iPredicates[i]);
-    if (IsFalse(aEnvironment, pred))
-    {
-      return false;
-    }
-    // If the result is not False, it should be True, else probably something is wrong (the expression returned unevaluated)
-    bool isTrue = IsTrue(aEnvironment, pred);
-    if (!isTrue)
-    {
+    for (std::size_t i = 0; i < n; ++i) {
+        LispPtr pred;
+        aEnvironment.iEvaluator->Eval(aEnvironment, pred, iPredicates[i]);
+        if (IsFalse(aEnvironment, pred)) {
+            return false;
+        }
+        // If the result is not False, it should be True, else probably
+        // something is wrong (the expression returned unevaluated)
+        bool isTrue = IsTrue(aEnvironment, pred);
+        if (!isTrue) {
 #define LIM_AL 60
-      LispString strout;
+            LispString strout;
 
-      aEnvironment.iErrorOutput << "The predicate\n\t";
-      PrintExpression(strout, iPredicates[i], aEnvironment, LIM_AL);
-      aEnvironment.iErrorOutput << strout;
-      aEnvironment.iErrorOutput << "\nevaluated to\n\t";
-      PrintExpression(strout, pred, aEnvironment, LIM_AL);
-      aEnvironment.iErrorOutput << strout << '\n';
+            aEnvironment.iErrorOutput << "The predicate\n\t";
+            PrintExpression(strout, iPredicates[i], aEnvironment, LIM_AL);
+            aEnvironment.iErrorOutput << strout;
+            aEnvironment.iErrorOutput << "\nevaluated to\n\t";
+            PrintExpression(strout, pred, aEnvironment, LIM_AL);
+            aEnvironment.iErrorOutput << strout << '\n';
 
-      ShowStack(aEnvironment);
-      throw LispErrMaxRecurseDepthReached();
+            ShowStack(aEnvironment);
+            throw LispErrMaxRecurseDepthReached();
+        }
     }
-  }
-  return true;
+    return true;
 }
 
-
-void YacasPatternPredicateBase::SetPatternVariables(LispEnvironment& aEnvironment,
-                                                    LispPtr* arguments)
+void YacasPatternPredicateBase::SetPatternVariables(
+    LispEnvironment& aEnvironment, LispPtr* arguments)
 {
     const std::size_t n = iVariables.size();
     for (std::size_t i = 0; i < n; ++i)
-        aEnvironment.NewLocal(iVariables[i],arguments[i]);
+        aEnvironment.NewLocal(iVariables[i], arguments[i]);
 }
 
-
 YacasPatternPredicateBase::~YacasPatternPredicateBase()
 {
-    for (const LispString* p: iVariables)
-        if (--p->iReferenceCount == 0)
-            delete p;
-
-    for (const YacasParamMatcherBase* p: iParamMatchers)
+    for (const YacasParamMatcherBase* p : iParamMatchers)
         delete p;
 }
